@@ -1,7 +1,9 @@
 import unittest
 import plotly.express as px
+import pandas as pd
 import cufflinks as cf
 from commodplot import commodplotutil as cpu
+from commodutil import transforms
 
 
 class TestCommodPlotUtil(unittest.TestCase):
@@ -32,6 +34,14 @@ class TestCommodPlotUtil(unittest.TestCase):
         self.assertTrue(isinstance(res['ch1'], str))
         self.assertTrue(isinstance(res['innerd']['ch2'], str))
 
+    def test_min_max_range(self):
+        df = cf.datagen.lines(1, 5000)
+        dft = transforms.seasonailse(df)
+        res = cpu.min_max_range(dft, shaded_range=5)
+        self.assertTrue(isinstance(res[0], pd.DataFrame))
+        self.assertTrue(isinstance(res[1], int))
+
+
 
 if __name__ == '__main__':
     unittest.main()
